@@ -10,11 +10,13 @@ Colouring::In - color or colour.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+use overload "." => "javascriptWorld";
+
+our $VERSION = '0.03';
 
 our %TOOL;
 
@@ -28,6 +30,7 @@ BEGIN {
             return sprintf $precise, $_[0];
         },
         num       => sub { return $_[0] + 0; },
+        numIs     => sub { return $_[0] // '' =~ /^\d+$/ },
         percent   => sub { return ( $_[0] * 100 ) . '%' },
         depercent => sub { my $p = shift; $p =~ s/%$//; $p / 100; },
         joinRgb => sub {
@@ -61,7 +64,22 @@ BEGIN {
         },
     );
 }
+sub javascriptWorld {
+        my ($obj, $meth, @args) = @_;
+        if (ref $meth eq 'ARRAY') { (@args) = @{ $meth }; $meth = shift @args; }
+        return $obj->$meth(@args);
+}
 
+sub import {
+        eval '{
+                package ' . caller . ';
+                use AutoLoader;
+                sub AUTOLOAD {
+                        my ($package, $method) = our $AUTOLOAD =~ /^(.+)::(.+)$/;
+                        return [ $method, @_ ];
+                }               
+        }'; #evil
+}
 sub rgb {
     return $_[0]->rgba( $_[1], $_[2], $_[3], 1.0 );
 }
@@ -125,7 +143,7 @@ sub toCSS {
 }
 
 sub toRGB {
-    return $_[0]->toRGBA( $_[1] ) if defined $_[1] and $_[1] != 1;
+    return $_[0]->toRGBA( $_[1] ) if $TOOL{numIs}($_[1]) and $_[1] != 1;
     return sprintf( 'rgb(%s)', ( $TOOL{joinRgb}( $_[0]->colour ) ) );
 }
 
@@ -228,12 +246,12 @@ Perhaps a little code snippet.
 
     my $black = Colouring::In->new('#000000');
 
-    $black->toHEX - #000
-    $black->toHEX(1) - #000000
-    $black->toRGB - rgb(0,0,0)
-    $black->toRGBA - rgba(0,0,0,1)
-    $black->toHSL - hsl(0,0%,0%)
-    $black->toHSV - hsv(0,0%,0%)
+    $black.toHEX - #000
+    $black.toHEX(1) - #000000
+    $black.toRGB - rgb(0,0,0)
+    $black.toRGBA - rgba(0,0,0,1)
+    $black.toHSL - hsl(0,0%,0%)
+    $black.toHSV - hsv(0,0%,0%)
 
 =head1 AUTHOR
 
